/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;
using NAnt.Core;
using NUnit.Framework;

namespace TopCoder.Test.Framework
{
    /// <summary>
    /// Tests the functionality of <c>ServerTaskException</c>.
    /// </summary>
    ///
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    [TestFixture]
    public class ServerTaskExceptionUnitTest
    {
        /// <summary>
        /// Represents a detail error message.
        /// </summary>
        private const string DETAIL_MESSAGE = "A detail message";

        /// <summary>
        /// Represents the cause exceptions of the error.
        /// </summary>
        private static readonly Exception[] CAUSE = new Exception[] { new Exception() };

        /// <summary>
        /// Tests the accuracy of <c>ServerTaskException(string, Exception[])</c>. The detail error message and
        /// cause exceptions array should be retrieved as set in the argument.
        /// </summary>
        [Test]
        public void TestServerTaskException_Accuracy()
        {
            ServerTaskException exception = new ServerTaskException(DETAIL_MESSAGE, CAUSE);

            Assert.AreEqual(DETAIL_MESSAGE, exception.Message,
                "The detail message should be the same as in argument.");
            Assert.AreEqual(CAUSE[0], exception.InnerException, "The cause should be the same as in argument.");
        }

        /// <summary>
        /// Tests the accuracy of <c>ServerTaskException(string, Exception[])</c>. The detail error message
        /// should be retrieved as set in the argument. Since the cause exceptions array is <c>null</c>,
        /// the innerException should be set to <c>null</c>.
        /// </summary>
        [Test]
        public void TestServerTaskException_NullCauseExceptionsAccuracy()
        {
            ServerTaskException exception = new ServerTaskException(DETAIL_MESSAGE, null);

            Assert.AreEqual(DETAIL_MESSAGE, exception.Message,
                "The detail message should be the same as in argument.");
            Assert.IsNull(exception.InnerException, "The cause should be null.");
        }

        /// <summary>
        /// Tests the accuracy of get-property of <c>InnerExceptions</c>.
        /// </summary>
        [Test]
        public void TestInnerExceptions_GetAccuracy()
        {
            ServerTaskException exception = new ServerTaskException(DETAIL_MESSAGE, CAUSE);

            Assert.AreEqual(CAUSE, exception.InnerExceptions,
                "The cause exceptions should be the same as in argument.");
        }
    }
}
