/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;
using NUnit.Framework;

namespace TopCoder.Test.Framework.Servers
{
    /// <summary>
    /// Tests the functionality of <c>ServerException</c>.
    /// </summary>
    ///
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    [TestFixture]
    public class ServerExceptionUnitTest
    {
        /// <summary>
        /// Represents a detail error message.
        /// </summary>
        private const string DETAIL_MESSAGE = "A detail message";

        /// <summary>
        /// Represents a original cause of the error.
        /// </summary>
        private static readonly Exception CAUSE = new Exception();

        /// <summary>
        /// Tests accuracy of <c>ServerException(string)</c>. The detail error message should be retrieved
        /// as set in the argument.
        /// </summary>
        [Test]
        public void TestServerException_StringAccuracy()
        {
            ServerException exception = new ServerException(DETAIL_MESSAGE);
            Assert.AreEqual(DETAIL_MESSAGE, exception.Message,
                "The detail message should be the same as in argument.");
        }

        /// <summary>
        /// Tests accuracy of <c>ServerException(string, Exception)</c>. The detail error message should be
        /// retrieved as set in the argument. The original cause of the error should be retrieved as set in the
        /// argument.
        /// </summary>
        [Test]
        public void TestServerException_StringExceptionAccuracy()
        {
            ServerException exception = new ServerException(DETAIL_MESSAGE, CAUSE);
            Assert.AreEqual(DETAIL_MESSAGE, exception.Message,
                "The detail message should be the same as in argument.");
            Assert.AreEqual(CAUSE, exception.InnerException, "The cause should be the same as in argument.");
        }

    }
}
