/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;
using System.Xml;
using NAnt.Core.Types;

namespace TopCoder.Test.Framework
{
    /// <summary>
    /// Defines utilities used in test cases.
    /// </summary>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    public sealed class UnitTestHelper
    {
        /// <summary>
        /// Creates a new instance of <c>UnitTestHelper</c> class.
        /// </summary>
        /// <remarks>
        /// This private constructor prevents the creation of a new instance.
        /// </remarks>
        private UnitTestHelper()
        {
        }

        /// <summary>
        /// Creates a new instance of <c>OptionCollection</c> with given option names and values.
        /// </summary>
        /// <param name="optionNames">The given option names colleciton.</param>
        /// <param name="optionValues">The given option values collection.</param>
        /// <returns>The created <c>OptionCollection</c> instance.</returns>
        public static OptionCollection CreateOptionCollection(string[] optionNames, string[] optionValues)
        {
            OptionCollection optionCollection = new OptionCollection();
            for (int i = 0; i < optionNames.Length; i++)
            {
                Option option = new Option();
                option.OptionName = optionNames[i];
                option.Value = optionValues[i];
                optionCollection.Add(option);
            }
            return optionCollection;
        }

        /// <summary>
        /// Gets the xml node from the given xml file by specific node name.
        /// </summary>
        /// <param name="fileName">The name of the xml file.</param>
        /// <param name="nodeName">The name of the node to load.</param>
        /// <returns>The loaded xml node.</returns>
        public static XmlNode GetXmlNode(string fileName, string nodeName)
        {
            XmlDocument document = new XmlDocument();
            document.Load(fileName);
            return document.DocumentElement[nodeName];
        }
    }
}
